<# 

# Set Default Applications using PowerShell script  
The PowerShell script will enable deployment teams to set Nitro Pro as a default application for viewing 
PDF files and choose default Internet Explorer add-ons for viewing PDF files in the browser.  

By running this script, Nitro Pro will be set as a default application at the local machine level (HKLM) for 
all users. Deployment teams can also choose to set Nitro Pro or Acrobat Internet Explorer add-on as 
default, which will enable users to view PDF files in the chosen IE add-on.  

**Preconditions**:  
- Nitro Pro must be installed on user's machines 
- Adobe Acrobat (Reader or Pro) must be installed on user's machines if setting Acrobat IE add-on as default 

**Parameters** 
The script includes three possible command line parameters, which can be used in different sequence.  

|  Comman line                      |  Outcome                                      |  OS versions          |
|-----------------------------------|-----------------------------------------------|-----------------------|
|-set_nitro_default_viewer          | Sets Nitro Pro as system default PDF viewer   | Windows 7 only        |
|-set_nitro_ie_plugin               | Sets Nitro Pro IE add-on as default           | Windows 7, 8.1 and 10 | 
|-set_acrobat_ie_plugin             | Sets Acrobat IE add-on as default             | Windows 7, 8.1 and 10 |

**Example 1**  
```
    powershell -noprofile -executionpolicy bypass -file ".\set-nitro-defaults.ps1" -set_nitro_default_viewer -set_nitro_ie_plugin
``` 
After script execution, Nitro Pro will be set as a default PDF viewer in system settings 
and Nitro Pro add-on will be set as default Internet Explorer add-on for PDF viewing in Internet browser

**Example 2** 
```
    powershell -noprofile -executionpolicy bypass -file ".\set-nitro-defaults.ps1" -set_acrobat_ie_plugin 
```
After script execution Acrobat add-on will be set as default Internet Explorer add-on for PDF viewing in Internet browser  

**Example 3** 
```
    powershell -noprofile -executionpolicy bypass -file ".\set-nitro-defaults.ps1" -set_nitro_default_viewer -set_acrobat_ie_plugin  
```
After script execution Nitro Pro will be set as default PDF viewer in system settings 
and Acrobat add-on will be set as default Internet Explorer add-on for PDF viewing in Internet browser

#>
function Set-IEPluginAsDefault 
{
    Param ([string]$ie_plugin_clsid)

    Set-Location -Path 'Registry::HKEY_CURRENT_USER\Software\Classes\MIME\Database\Content Type\application/pdf'
    $current_value = (Get-ItemProperty . -Name 'CLSID').'CLSID'

    If(-Not $current_value.Equals($ie_plugin_clsid))  {
        
        Set-ItemProperty . -Name 'CLSID' -Value $ie_plugin_clsid
        $current_value=(Get-ItemProperty . -Name 'CLSID').'CLSID'
   
        if ($current_value.Equals($ie_plugin_clsid)) {
            Write-Host "[Result] IE Plugin successfuly changed"
        }
        else {
            Write-Host "[Result] IE Plugin fail to change"
        }
    }
    Else {
        Write-Host "[Result] IE Plugin already changed.  "
    } 
}


function Set-NitroPdfAsDefaultViewer
{
    Set-Location -Path Registry::HKEY_LOCAL_MACHINE\SOFTWARE\Classes\.pdf
    $value_to_set=(Get-ItemProperty . -Name '(default)').'(default)'
    $succeeded_result = $true
    
    If($value_to_set -eq $null -or -not $value_to_set.contains("NitroPDF"))  {

        $value_to_set = 'NitroPDF.Document.11'

        Set-ItemProperty . -Name '(default)' -Value $value_to_set 
        $current_value=(Get-ItemProperty . -Name '(default)').'(default)'
        $succeeded_result = ($current_value.Equals($value_to_set)) 
    }
    
    $user_choice = Get-Item Registry::HKEY_CURRENT_USER\Software\Microsoft\Windows\CurrentVersion\Explorer\FileExts\.pdf\UserChoice

    if ($user_choice -ne $null -and $succeeded_result -eq $true)
    {
        $hkey = 2147483649 
        $hsubkey = "Software\Microsoft\Windows\CurrentVersion\Explorer\FileExts\.pdf\UserChoice"
        $reg = [wmiclass]"root\default:StdRegProv"
        $ace = $reg.GetSecurityDescriptor($hkey,$hsubkey).Descriptor.DACL

        $reg.psbase.Scope.Options.EnablePrivileges = $true
        $sd = ([WMIClass] "Win32_SecurityDescriptor").CreateInstance()
        $sd.ControlFlags = 0x0004

        for($i=0;$i -lt $ace.length;$i++)
        {
            if($ace[$i].AceType -ne 1)
            {
                $SD.dacl += $ace[$i] 
            }
        }
        $reg.SetSecurityDescriptor($hkey,$hsubkey,$sd)
        
        Remove-Item -Path 'hkcu:\Software\Microsoft\Windows\CurrentVersion\Explorer\FileExts\.pdf\UserChoice' 
    
        $item_to_check = Get-Item -Path 'hkcu:\Software\Microsoft\Windows\CurrentVersion\Explorer\FileExts\.pdf\UserChoice' 
        $succeeded_result = $item_to_check -eq $null
    }
    
    if ($succeeded_result -eq $true) {
        Write-Host "[Result] Nitro PDF as default viewer was set successfuly"
    }
    else {
        Write-Host "[Result] Error occured during setting Nitro PDF as default viewer"
    }
}


$ErrorActionPreference = "SilentlyContinue"
    
Write-Host "[Start] Command parsing" 

foreach ($command in $args)
{
    try {

        if($command.Equals("-set_nitro_default_viewer")) {
            Write-Host "[Execute Command] Nitro Pro will be set as default PDF viewer in system settings" 
            Set-NitroPdfAsDefaultViewer
        } 
        elseif($command.Equals("-set_nitro_ie_plugin")) {
            Write-Host "[Execute Command] Nitro Pro add-on will be set as default Internet Explorer add-on for PDF viewing in Internet browser" 
            Set-IEPluginAsDefault -ie_plugin_clsid "{3A7B4EA1-8CA8-4629-B09A-FB4EE0632BA8}"
        }
        elseif($command.Equals("-set_acrobat_ie_plugin")) {
            Write-Host "[Execute Command] Acrobat add-on will be set as default Internet Explorer add-on for PDF viewing in Internet browser" 
            Set-IEPluginAsDefault -ie_plugin_clsid "{CA8A9780-280D-11CF-A24D-444553540000}"
        }
        else {
            Write-Host "[Skipped Command] Unknown command : " + $command
        }
    }
    catch {
        Write-Host "[Error] Exception occured during command execution." 
        Write-Host "[Exception] "$error[0].Exception
    }
}
    
Write-Host "[Finish] Complete." 


